.. safe-eth-py documentation main file, created by
   sphinx-quickstart on Fri Jul  9 12:45:20 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Introduction
============

Safe-eth-py includes a set of libraries to work with Ethereum and Gnosis projects:
  - `EthereumClient`, a wrapper over Web3.py `Web3` client including utilities to deal with ERC20/721
    tokens and tracing.
  - `Gnosis Safe <https://github.com/safe-global/safe-contracts>`_ classes and utilities.
  - Price oracles for `Uniswap`, `Kyber`...
  - Django serializers, models and utils.

Table of Contents
---------------------

.. toctree::
    :maxdepth: 2
    :caption: Intro

    quickstart

.. toctree::
   :maxdepth: 2
   :caption: API:

   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
